package tv.smartclip.smartclientandroid.app.reference

import android.content.Intent
import android.os.Bundle
import android.view.Menu
import android.view.MenuItem
import androidx.appcompat.app.AppCompatActivity
import tv.smartclip.smartclientandroid.lib.utils.Log

/**
 * Base activity whose purpose is to handle the creation and management of the menu.
 */
abstract class BaseActivity : AppCompatActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setTitle(R.string.app_name_long)
        Log.initialize(this,
                logLevel = if (BuildConfig.DEBUG) Log.LogLevel.VERBOSE else Log.LogLevel.WARN,
                addCallOrigin = BuildConfig.DEBUG,
                useLogCache = false)

    }

    override fun setTitle(title: CharSequence) {
        val supportActionBar = supportActionBar
        supportActionBar?.title = title
    }

    override fun onCreateOptionsMenu(menu: Menu): Boolean {
        val inflater = menuInflater
        inflater.inflate(R.menu.use_case_menu, menu)
        return true
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return when (item.itemId) {
            R.id.nav_instream_exo -> {
                startActivity(Intent(this, InstreamExoWrapperActivity::class.java))
                finish()
                true
            }
            R.id.nav_instream_custom -> {
                startActivity(Intent(this, AbsVideoPlayerWrapperActivity::class.java))
                finish()
                true
            }
            R.id.nav_outstream -> {
                startActivity(Intent(this, OutStreamActivity::class.java))
                finish()
                true
            }
            else -> super.onOptionsItemSelected(item)
        }
    }
}
